#include <stdio.h> /* fprintf,fgets,fputs,fopen,fclose,perror,sscanf */
#include <stdlib.h> /* the std stuff */
#include <string.h> /* strtok */
#include "lsatheader.h"

void usage()
{
	fprintf(stderr, "Usage is lsat [options]\n");
	fprintf(stderr, "Options:\n");
	fprintf(stderr, "		-v					verbose\n");
	fprintf(stderr, "		-o<filename>	Output file name\n");
	exit(8);
}

int versions(char release[], char kernel[])
{
	/* some local vars... */
	FILE *infile;
	char *ptr;
	char line[1024];
	char tempstring[50];
	int  linecount=0;
	int  field=0;
	int  i=0;
	/* open input file for read... 									*/
	infile = fopen("/tmp/templist.txt", "r");
	if (infile == NULL)
	{
		/* rhut-rho */
		perror("Can't open the file we just made!?!\n");
		perror("Giving up, check perms or something...\n");
		return(-1);
	}

	/* get a line from the file... it should contain only 2					*/
	/* 1st line is uname -a, so the third field is the kernel version 	*/
	/* 2nd line is (maybee) redhat-release. We want the number, which    */
	/* is the 5th element :)															*/
	while (fgets(line, sizeof(line), infile) != NULL)
	{
		/* (re)set field...	*/
		field=0;
		ptr = strtok(line, ", \"\n");
		if (ptr == NULL)
		{
			break;
		}
		/* not blank?? Do some stuff...			*/
		while (ptr != NULL)
		{
			/* if linecount == 0, get 3rd field */
			if (sscanf(ptr, "%s", &tempstring) < 1)
			{
				perror("sccanf bit the dust");
				return(-1);
			}
			if ((field == 2) && (linecount == 0))
			{
				for (i = 0; i < 50; i++)
				{
					kernel[i]=tempstring[i];
				}
			}
			if ((field == 4) && (linecount == 1))
			{
				for (i = 0; i < 50; i++)
				{
					release[i]=tempstring[i];
				}
			}
			ptr = strtok(NULL, ", \"\n");
			if (ptr == NULL)
			{
				/* freak out */
				break;
			}
			field++;
		}
		linecount++;
	}
	return(0);
}


int main(int argc, char *argv[])
{
	int retval=0;
	int verbose=0;
	char release[50];
	char kernel[50];
	char *out_file="lsat.out";
	FILE *tempptr;

	/* some options that are not yet implimented :) */
	while ((argc > 1) && (argv[1][0]=='-'))
	{
		/* argv[1][1] is 1st option char */
		switch (argv[1][1])
		{
			case 'v':
				verbose = 1;
				break;

			/* outfile 					*/
			/* -o<name> is format 	*/

			case 'o':
				out_file = &argv[1][2];
				break;

			default:
				printf("Bad option %s\n", argv[1]);
				usage();
		}
		++argv;
		--argc;
	}

	/* First off, get the uname and redhat-release, if there 	*/
	/* is one...																*/
	/* this is silly, I should know how to do this more easily 	*/

	if ( (system("uname -a >> /tmp/templist.txt")) < 0)
	{
		/* rhut-rho...something bad happened. 					*/
		perror("Problem executing pwd...\n");
		return(0);
	}
	if ( (system("cat /etc/redhat-release >> /tmp/templist.txt")) < 0)
	{
		/* Hrm, perhaps we are not on a redhat system		*/
		/* we will do something else to fix that later on  */
		;
	}

	/* read that in, check kernel version and if we are	*/
	/* on a redhat box, the redhat-release...					*/
	retval = versions(release, kernel);
	if (retval < 0)
	{
		/* something went wrong... 								*/
		perror("Problem in versions function.\n");
		return(0);
	}

	if ( (system("rm -f /tmp/templist.txt")) < 0)
	{
		/* rhut-rho...something bad happened.					*/
		perror("Problem rm'ing tempfile...\n");
		return(0);
	}

	/* secondly, check to see if lsat.out exists.   */
	/* if it does, call it lsat.old and rm lsat.out	*/

	tempptr = fopen(out_file, "r");
	if (tempptr == NULL)
	{
		/* great the outfile does not exist */
		/* do nothing... <smile>	    */
		;		
	}
	else
	{
		/* the outfile exists. lets not     */
		/* append to it, but back it up     */
		fclose(tempptr);
		if ((system("mv -f lsat.out lsat.old")) < 0)
		{
			/* rhut-rho... problems... */
			perror("Problem backing up lsat.out file.\n");
			perror("Check perms on the cwd please...\n");
			return(-1);
		}
	}

	checkrpms(release, kernel, out_file);
	checkinetd(release, out_file);
	return(0);
}


/**********************************************************************
Copyright (C) 2002 Robert Minvielle (number9)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
**********************************************************************/
